@@ -1,4 +1,4 @@
-/* Copyright (C) 2021-2023 Free Software Foundation, Inc.
+/* Copyright (C) 2021-2026 Free Software Foundation, Inc.
    Contributed by Oracle.
 
    This file is part of GNU Binutils.
@@ -30,8 +30,6 @@
 
 #include "Emsgnum.h" /* for COL_ERROR_*, etc. symbols */
 
-#define SP_REMOTE_PROTOCOL_VERSION "12.4.1"
-
 #define SP_GROUP_HEADER         "#analyzer experiment group"
 
 /* Experiment name macro definitions */
@@ -41,6 +39,23 @@
 #define IS_DESC_EXPT(exptname)  (strstr(exptname,DESCENDANT_EXPT_KEY) != NULL)
 #define IS_FNDR_EXPT(exptname)  (strstr(exptname,DESCENDANT_EXPT_KEY) == NULL)
 
+// environment variables that must be forwarded to libcollector
+#define SP_COLLECTOR_PARAMS         "SP_COLLECTOR_PARAMS"
+#define SP_COLLECTOR_EXPNAME        "SP_COLLECTOR_EXPNAME"
+#define SP_COLLECTOR_FOLLOW_SPEC    "SP_COLLECTOR_FOLLOW_SPEC"
+#define SP_COLLECTOR_FOUNDER        "SP_COLLECTOR_FOUNDER"
+#define SP_PRELOAD_STRINGS          "SP_COLLECTOR_PRELOAD"
+#define LD_PRELOAD_STRINGS          "LD_PRELOAD"
+#define SP_LIBPATH_STRINGS          "SP_COLLECTOR_LIBRARY_PATH"
+#define LD_LIBPATH_STRINGS          "LD_LIBRARY_PATH"
+#define JAVA_TOOL_OPTIONS           "JAVA_TOOL_OPTIONS"
+#define COLLECTOR_JVMTI_OPTION      "-agentlib:gp-collector"
+#define LIBGP_COLLECTOR             "libgp-collector.so"
+#define GPROFNG_PRELOAD_LIBDIRS     "GPROFNG_PRELOAD_LIBDIRS"
+#define SP_COLLECTOR_ORIGIN_COLLECT "SP_COLLECTOR_ORIGIN_COLLECT"
+#define SP_COLLECTOR_DEBUG          "SP_COLLECTOR_DEBUG"
+#define SP_COLLECTOR_TRACELEVEL     "SP_COLLECTOR_TRACELEVEL"
+
 /* File name definitions */
 #define SP_ARCHIVES_DIR         "archives"
 #define SP_ARCHIVE_LOG_FILE     "archive.log"
@@ -88,70 +103,31 @@
 
 /* records for log and loadobjects files */
 /* note that these are in alphabetical order */
-#define SP_JCMD_ARCH            "architecture"
 #define SP_JCMD_ARCHIVE         "archive_run"
-#define SP_JCMD_ARGLIST         "arglist"
 #define SP_JCMD_BLKSZ           "blksz"
 #define SP_JCMD_CERROR          "cerror"
-#define SP_JCMD_CLASS_LOAD      "class_load"
-#define SP_JCMD_CLASS_UNLOAD    "class_unload"
 #define SP_JCMD_COLLENV         "collenv"
 #define SP_JCMD_COMMENT         "comment"
-#define SP_JCMD_CPUID           "cpuid"
 #define SP_JCMD_CWARN           "cwarn"
-#define SP_JCMD_CWD             "cwd"
-#define SP_JCMD_CVERSION        "cversion"
-#define SP_JCMD_DATARACE        "datarace"
-#define SP_JCMD_DEADLOCK        "deadlock"
 #define SP_JCMD_DELAYSTART      "delay_start"
 #define SP_JCMD_DESC_START      "desc_start"
 #define SP_JCMD_DESC_STARTED    "desc_started"
-#define SP_JCMD_DVERSION        "dversion"
 #define SP_JCMD_EXEC_START      "exec_start"
 #define SP_JCMD_EXEC_ERROR      "exec_error"
 #define SP_JCMD_EXIT            "exit"
-#define SP_JCMD_EXPT_DURATION   "exp_duration"
 #define SP_JCMD_FAKETIME        "faketime"
-#define SP_JCMD_FN_LOAD         "fn_load"
-#define SP_JCMD_FN_UNLOAD       "fn_unload"
-#define SP_JCMD_FUN_MAP         "fun_map"
-#define SP_JCMD_FUN_UNMAP       "fun_unmap"
 #define SP_JCMD_HEAPTRACE       "heaptrace"
-#define SP_JCMD_HOSTNAME        "hostname"
 #define SP_JCMD_HWC_DEFAULT     "hwc_default"
 #define SP_JCMD_HW_COUNTER      "hwcounter"
-#define SP_JCMD_HW_SIM_CTR      "hwsimctr"
 #define SP_JCMD_IOTRACE         "iotrace"
-#define SP_JCMD_JCM_LOAD        "jcm_load"
-#define SP_JCMD_JCM_UNLOAD      "jcm_unload"
-#define SP_JCMD_JCM_MAP         "jcm_map"
-#define SP_JCMD_JCM_UNMAP       "jcm_unmap"
 #define SP_JCMD_JTHREND         "jthread_end"
 #define SP_JCMD_JTHRSTART       "jthread_start"
 #define SP_JCMD_GCEND           "gc_end"
 #define SP_JCMD_GCSTART         "gc_start"
 #define SP_JCMD_JVERSION        "jversion"
-//#define SP_JCMD_KPROFILE        "kprofile"    /* TBR */
 #define SP_JCMD_LIMIT           "limit"
 #define SP_JCMD_LINETRACE       "linetrace"
-#define SP_JCMD_LO_OPEN         "lo_open"
-#define SP_JCMD_LO_CLOSE        "lo_close"
-#define SP_JCMD_MOD_OPEN        "mod_open"
-#define SP_JCMD_MPIEXP          "MPIexperiment"
-#define SP_JCMD_MPI_NO_TRACE    "MPI_no_trace"
-#define SP_JCMD_MPIOMPVER       "mpi_openmpi_version"
-#define SP_JCMD_MPITRACEVER     "mpi_trace_version"
-#define SP_JCMD_MPIPP           "mpipp"
-#define SP_JCMD_MPIPPERR        "mpipp_err"
-#define SP_JCMD_MPIPPWARN       "mpipp_warn"
-#define SP_JCMD_MPISTATE        "mpistate"
-#define SP_JCMD_MPITRACE        "mpitrace" /* backwards compat only */
-#define SP_JCMD_MPVIEW          "mpview"
-#define SP_JCMD_MSGTRACE        "msgtrace"
 #define SP_JCMD_NOIDLE          "noidle"
-#define SP_JCMD_OMPTRACE        "omptrace"
-#define SP_JCMD_OS              "os"
-#define SP_JCMD_PAGESIZE        "pagesize"
 #define SP_JCMD_PAUSE           "pause"
 #define SP_JCMD_PAUSE_SIG       "pause_signal"
 #define SP_JCMD_PROFILE         "profile"
@@ -160,21 +136,15 @@
 #define SP_JCMD_SAMPLE          "sample"
 #define SP_JCMD_SAMPLE_PERIOD   "sample_period"
 #define SP_JCMD_SAMPLE_SIG      "sample_signal"
-#define SP_JCMD_SEGMENT_MAP     "seg_map"
-#define SP_JCMD_SEGMENT_UNMAP   "seg_unmap"
 #define SP_JCMD_SRCHPATH        "search_path"
 #define SP_JCMD_STACKBASE       "stackbase"
-#define SP_JCMD_SUNPERF         "sunperf"
 #define SP_JCMD_SYNCTRACE       "synctrace"
 #define SP_JCMD_TERMINATE       "terminate"
 #define SP_JCMD_THREAD_PAUSE    "thread_pause"
 #define SP_JCMD_THREAD_RESUME   "thread_resume"
-#define SP_JCMD_USERNAME        "username"
 #define SP_JCMD_VERSION         "version"
-#define SP_JCMD_WSIZE           "wsize"
 
 /* strings naming memory-segments */
-#define SP_MAP_ANON             "Anon"
 #define SP_MAP_HEAP             "Heap"
 #define SP_MAP_STACK            "Stack"
 #define SP_MAP_SHMEM            "SHMid"
