@@ -1,4 +1,4 @@
-/* Copyright (C) 2021-2023 Free Software Foundation, Inc.
+/* Copyright (C) 2021-2026 Free Software Foundation, Inc.
    Contributed by Oracle.
 
    This file is part of GNU Binutils.
@@ -36,12 +36,6 @@
 #include "gp-experiment.h"
 #include "memmgr.h"
 
-/* TprintfT(<level>,...) definitions.  Adjust per module as needed */
-#define DBG_LT0 0 // for high-level configuration, unexpected errors/warnings
-#define DBG_LT1 1 // for configuration details, warnings
-#define DBG_LT2 2
-#define DBG_LT3 3
-
 /* ------------- Data and prototypes for block management --------- */
 #define IO_BLK      0 /* Concurrent requests */
 #define IO_SEQ      1 /* All requests are sequential, f.e. JAVA_CLASSES */
