@@ -1,6 +1,6 @@
 /* coff information for Intel 386/486.
    
-   Copyright (C) 2001-2023 Free Software Foundation, Inc.
+   Copyright (C) 2001-2026 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -17,11 +17,7 @@
    Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston,
    MA 02110-1301, USA.  */
 
-#define L_LNNO_SIZE 2
-#define INCLUDE_COMDAT_FIELDS_IN_AUXENT
-#include "coff/external.h"
-
-#define COFF_PAGE_SIZE	0x1000
+#include "coff/x86.h"
 
 /* Bits for f_flags:
  	F_RELFLG	Relocation info stripped from file
@@ -43,15 +39,6 @@
 
 #define LYNXCOFFMAGIC	0415
 
-/* .NET DLLs XOR the Machine number (above) with an override to
-    indicate that the DLL contains OS-specific machine code rather
-    than just IL or bytecode. See
-    https://github.com/dotnet/coreclr/blob/6f7aa7967c607b8c667518314ab937c0d7547025/src/inc/pedecoder.h#L94-L107. */
-#define IMAGE_FILE_MACHINE_NATIVE_APPLE_OVERRIDE   0x4644
-#define IMAGE_FILE_MACHINE_NATIVE_FREEBSD_OVERRIDE 0xadc4
-#define IMAGE_FILE_MACHINE_NATIVE_LINUX_OVERRIDE   0x7b79
-#define IMAGE_FILE_MACHINE_NATIVE_NETBSD_OVERRIDE  0x1993
-
 /* Used in some .NET DLLs that target a specific OS.  */
 #define I386_APPLE_MAGIC   (I386MAGIC ^ IMAGE_FILE_MACHINE_NATIVE_APPLE_OVERRIDE)
 #define I386_FREEBSD_MAGIC (I386MAGIC ^ IMAGE_FILE_MACHINE_NATIVE_FREEBSD_OVERRIDE)
@@ -72,25 +59,6 @@
 #define STMAGIC		0401	/* Target shlib.  */
 #define SHMAGIC		0443	/* Host shlib.  */
 
-/* Define some NT default values.  */
-/*  #define NT_IMAGE_BASE        0x400000 moved to internal.h */
-#define NT_SECTION_ALIGNMENT 0x1000
-#define NT_FILE_ALIGNMENT    0x200
-#define NT_DEF_RESERVE       0x100000
-#define NT_DEF_COMMIT        0x1000
-
-/* Relocation directives.  */
-
-struct external_reloc
-{
-  char r_vaddr[4];
-  char r_symndx[4];
-  char r_type[2];
-};
-
-#define RELOC struct external_reloc
-#define RELSZ 10
-
 /* i386 Relocations.  */
 
 #define R_DIR32		 6
