@@ -9,8 +9,8 @@ MAXPAGESIZE=256
 ENTRY=_start
 EMBEDDED=yes
 OTHER_EXCLUDE_FILES='*frvend.o'
-OTHER_END_SYMBOLS='__end = .;'
-DATA_START_SYMBOLS='__data_start = . ;'
+OTHER_END_SYMBOLS="${CREATE_SHLIB+PROVIDE (}__end = .${CREATE_SHLIB+)};"
+DATA_START_SYMBOLS="${CREATE_SHLIB+PROVIDE (}__data_start = .${CREATE_SHLIB+)};"
 STACK_ADDR=0x200000
 NOP=0x80000000
 OTHER_GOT_SYMBOLS='
