@@ -1291,6 +1291,7 @@ ldelf_after_open (int use_libpath, int native, int is_linux, int is_freebsd,
 	}
     }
 
+  get_elf_backend_data (link_info.output_bfd)->setup_object_attributes (&link_info);
   get_elf_backend_data (link_info.output_bfd)->setup_gnu_properties (&link_info);
 
   /* Do not allow executable files to be used as inputs to the link.  */
@@ -1329,7 +1330,7 @@ ldelf_after_open (int use_libpath, int native, int is_linux, int is_freebsd,
 	  flagword flags = SEC_READONLY | (link_info.execstack ? SEC_CODE : 0);
 	  s = bfd_make_section_with_flags (link_info.input_bfds,
 					   ".note.GNU-stack", flags);
-	  if (s)
+	  if (s && bfd_get_flavour (s->owner) == bfd_target_elf_flavour)
 	    elf_section_type (s) = SHT_NOTE;
 	}
       return;
